@@ -17,5 +17,4 @@
 ;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 (in-package "TWINLISP")
 ; copying methods
-(defmethod _copy_ ((obj t)) obj)
-(defmethod _deepcopy_ ((obj t)) obj)
+(defgeneric _copy_ (obj) (:method ((obj t)) obj))
