@@ -31,16 +31,14 @@
 (const _DOT_FLOAT_RE (regexp:regexp-compile (_+_ (_+_ "^\\.[0-9]\\+[esfdlESFDL][+\\-]\\?[0-9]\\+" "\\|") "^\\.[0-9]\\+")))
 (const _NUMBER_RE (regexp:regexp-compile (_+_ (_+_ (_+_ (_+_ "^[0-9]\\+\\.\\?[0-9]*[esfdlESFDL][+\\-]\\?[0-9]\\+" "\\|") "^[0-9]\\+\\.[0-9]\\+") "\\|") "^[0-9]\\+\\.\\?")))
 (defun makeStrElem (elemType value strNum start end) (new StrElem :type elemType :value value :lineNum strNum :start start :end end))
-(defun _startStringPhase (strNum startIndex marks) (tl-append marks (makeStrElem STR_START_ELEM (string #\") ;"
- strNum startIndex (_+_ startIndex 1))) (values (_+_ startIndex 1) STRING_PHASE))
+(defun _startStringPhase (strNum startIndex marks) (tl-append marks (makeStrElem STR_START_ELEM (string #\") strNum startIndex (_+_ startIndex 1))) (values (_+_ startIndex 1) STRING_PHASE))
 (defun _findEndOfExprInStr (st startIndex termChars) "    Expressions are expected to end by any symbol in termChars. If the first
     return parameter is True, then expression was terminated correctly. If
     it is False, then the end of the line was reached.
     " (do* ((end startIndex)) ((_>=_ end (len st)) (values nil end)) (let (ch) (setf ch (_getitem_ st end)) (cond ((_!=_ (tl-count termChars ch) 0) (return-from nil (values t end))) ((_==_ ch #\\) (cond ((_<_ (_+_ end 1) (len st)) (setf end (_+_ end 2))) (t (setf end (_+_ end 1))))) (t (setf end (_+_ end 1)))))))
 (defun _findEndOfExpr (st startIndex termChars) "    Symbol is terminated by one of termChars, or the end of line.
     " (nth-value 1 (_findEndOfExprInStr st startIndex termChars)))
-(defun _procStringPhase (initStr strNum startIndex marks) (let (st) (setf st initStr) (let (endingInside end) (setf (values endingInside end) (_findEndOfExprInStr st startIndex (_make-vector_ :initContent (list #\")))) ;"
- (let (elemType phase) (setf (values elemType phase end) (cond (endingInside ; include also ending quote
+(defun _procStringPhase (initStr strNum startIndex marks) (let (st) (setf st initStr) (let (endingInside end) (setf (values endingInside end) (_findEndOfExprInStr st startIndex (_make-vector_ :initContent (list #\")))) (let (elemType phase) (setf (values elemType phase end) (cond (endingInside ; include also ending quote
  (values STR_END_ELEM REG_PHASE (_+_ end 1))) (t (setf st (_+_ st #\Newline)) (values STR_MID_ELEM STRING_PHASE (len st))))) (tl-append marks (makeStrElem elemType (_getitem_ st (_make-slice_ startIndex end nil)) strNum startIndex end)) (values st end phase)))))
 (defun _procCLispPhase (st strNum startIndex marks) (let (match) (setf match (regexp:regexp-exec _CLISP_END_RE st :start startIndex)) (let (end codeEnd phase elemType) (setf (values end codeEnd phase elemType) (cond (match (values (_+_ (slot-value match 'regexp::start) (len CLISP_END_STRING)) (slot-value match 'regexp::start) REG_PHASE CLISP_END_ELEM)) (t (values (len st) (len st) CLISP_PHASE CLISP_MID_ELEM)))) (tl-append marks (makeStrElem elemType (_+_ (_getitem_ st (_make-slice_ startIndex codeEnd nil)) #\Newline) strNum startIndex end)) (values end phase))))
 (defun _procAmpName (st strNum startIndex marks) ; how long is a symbol?
@@ -54,8 +52,7 @@
  (values (_+_ startIndex 1) ".")))) (tl-append marks (makeStrElem elemType (_getitem_ st (_make-slice_ startIndex end nil)) strNum startIndex end)) end)))
 (defun _procNum (st strNum startIndex marks) (let (end) (setf end (slot-value (regexp:regexp-exec _NUMBER_RE st :start startIndex) 'regexp::end)) (tl-append marks (makeStrElem NUM_ELEM (_getitem_ st (_make-slice_ startIndex end nil)) strNum startIndex end)) end))
 (defun markElemsInStr (st strNum &optional (initPhase REG_PHASE)) (let (marks) (setf marks (_make-vector_)) (let (phase) (setf phase initPhase) (let (startIndex) (setf startIndex 0) (do () ((_>=_ startIndex (len st))) (tl-case phase nil ((STRING_PHASE) (setf (values st startIndex phase) (_procStringPhase st strNum startIndex marks))) ((CLISP_PHASE) (setf (values startIndex phase) (_procCLispPhase st strNum startIndex marks))) ((REG_PHASE) (let (match) (setf match (regexp:regexp-exec _WHITE_RE st :start startIndex)) (cond (match (tl-append marks (makeStrElem WHITE_ELEM nil strNum startIndex (slot-value match 'regexp::end))) (setf startIndex (slot-value match 'regexp::end))) (t (setf match (regexp:regexp-exec _NON_WHITE_RE st :start startIndex)) (let (nonWhiteEnd) (setf nonWhiteEnd (slot-value match 'regexp::end)) (setf match (regexp:regexp-exec _ALPHA_NUM_RE st :start startIndex :end nonWhiteEnd)) (cond ((_not_ match) ; have some special charachter (non alpha-num) in the beginning
- (case (_getitem_ st startIndex) ((#\&) (setf startIndex (_procAmpName st strNum startIndex marks))) ((#\#) (setf startIndex (_procSpecSynt st strNum startIndex marks))) ((#\.) (setf startIndex (_procDotOrNum st strNum startIndex marks))) ((#\") ;"
- (setf (values startIndex phase) (_startStringPhase strNum startIndex marks))) ((#\;) ; semicolomn starts comment, which extends till the end
+ (case (_getitem_ st startIndex) ((#\&) (setf startIndex (_procAmpName st strNum startIndex marks))) ((#\#) (setf startIndex (_procSpecSynt st strNum startIndex marks))) ((#\.) (setf startIndex (_procDotOrNum st strNum startIndex marks))) ((#\") (setf (values startIndex phase) (_startStringPhase strNum startIndex marks))) ((#\;) ; semicolomn starts comment, which extends till the end
  (tl-append marks (makeStrElem COMM_ELEM (_getitem_ st (_make-slice_ startIndex (len st) nil)) strNum startIndex (len st))) (setf startIndex (len st))) (otherwise (setf startIndex (_procSpecialChars st strNum startIndex marks))))) (t ; have an alpha-num symbol or a number
  (let (alphaNumEnd) (setf alphaNumEnd (slot-value match 'regexp::end)) (setf match (regexp:regexp-exec _ONE_DIGIT_RE st :start startIndex)) (cond (match (setf startIndex (_procNum st strNum startIndex marks))) (t (setf match (regexp:regexp-exec _CLISP_START_RE st :start startIndex)) (cond (match (tl-append marks (makeStrElem CLISP_START_ELEM nil strNum startIndex nil)) (setf phase CLISP_PHASE) (setf startIndex (slot-value match 'regexp::end))) (t ; have alpha-numeric symbol
  (let (symb) (setf symb (_getitem_ st (_make-slice_ startIndex alphaNumEnd nil))) (let (elType) (setf elType (cond ((_==_ (tl-count SPEC_SYMB symb) 0) SYMB_ELEM) (t (cond ((_==_ (tl-count OPER_SYMB symb) 0) SPEC_SYMB_ELEM) (t symb))))) (tl-append marks (makeStrElem elType symb strNum startIndex alphaNumEnd)) (setf startIndex alphaNumEnd))))))))))))))))) (cond ((_and_ (_==_ (len st) 0) (_==_ phase STRING_PHASE)) (tl-append marks (makeStrElem STR_MID_ELEM (string #\Newline) strNum 0 1)))) (tl-append marks (makeStrElem LINE_END_ELEM nil strNum nil nil)) (values marks phase)))))
